** Jeffrey Clemens 5.11.2017
** Desciption: Clean and Analyze SIPP Data for "The Minimum Wage and the Great 
** Recession: A Response to Zipperer and Recapitulation of the Evidence"

** Notes: Running this file requires the following data sets:
** 1) sippl08puw`i'.dta for i=1/15 (available through NBER)
** See: http://www.nber.org/data/survey-of-income-and-program-participation-sipp-data.html
** The files sippl08puw`i'.dta are produced by downloading l08puw`i'.dat and 
** running 08w`i'.do and 08w`i'.dct within the required directory structure.
** 2) Macro_Controls.dta
** The file Macro_Controls.dta is available either through the replication packet in 
** which you have obtained this .do file or, as needed, from Jeffrey Clemens. 
** The file contains an FHFA median house price index which, as of 5/11/2017,
** could be downloaded directly from:
** https://www.fhfa.gov/DataTools/Downloads/Documents/HPI/HPI_AT_state.csv
** Note that the median house price index is the only variable from Macro_Controls.dta
** that is required to estimate the "baseline" specification.  Additional control
** variables in Macro_Controls.dta include standard state level data on the employment
** rate, the unemployment rate, and personal income per capita.  The employment
** series are available through the Bureau of Labor Statistics and the personal
** income series is available through the Bureau of Economic Analysis.
** 3) ConstructionBEAForMerge.dta
** This data set contains construction output data from the Bureau of Economic
** Analysis. Like Macro_Controls.dta, it is available either through the replication 
** packet in which you have obtained this .do file or, as needed, from Jeffrey Clemens.
** 4) MinimumWageRatesByStateAndMonth
** This is a modestly revised version of the minimum wage panel from the replication
** materials associated with "Effects of the Minimum Wage on Employment Dynamics" by
** Jonathan Meer and Jeremy West (JHR, 2016).  Note that only states' January 2008
** minimum wage rates are needed to replicate our "baseline" specification.
** These minimum wage rates can, as of 5/11/2017, be found at the following link 
** from the Bureau of Labor Statistics: https://www.dol.gov/whd/state/stateMinWageHis.htm

clear
capture log close 

set matsize 5000

* Set up directory structure
global sippdatadirectory C:\Users\cleme\Dropbox\Min Wage\Raw_SIPP_Data\sipp\2008
global cpsdatadirectory C:\Users\cleme\Dropbox\Min Wage\Data\CPS
global workdirectory C:\Users\cleme\Dropbox\Min Wage\ZippererRebutallPaper\WithinRegionCritiqueReplicationArchive
global logdirectory C:\Users\cleme\Dropbox\Min Wage\ZippererRebutallPaper\WithinRegionCritiqueReplicationArchive
global additionaldatadirectory C:\Users\cleme\Dropbox\Min Wage\ZippererRebutallPaper\WithinRegionCritiqueReplicationArchive
global resultsdirectory C:\Users\cleme\Dropbox\Min Wage\ZippererRebutallPaper\WithinRegionCritiqueReplicationArchive\Results

cd "${workdirectory}"

capture log close
log using "${logdirectory}/WithinRegionCritique_SIPPAnalysis.log", replace


*==================================================
*===== Load SIPP Waves =====
*==================================================
clear

forvalues i=1/15 {
preserve
use "${sippdatadirectory}/sippl08puw`i'.dta", clear
keep ewelac* ersend* erendb* eenrlm eunion1 ersnowrk eptwrk ejbhrs1 rmwkwjb rwksperm rpyper1 ecflag ebuscntr tsbdate1 tebdate1 ejobcntr tfipsst tftotinc rfnkids ulftmain efnp ejbind1 thtrninc eeducate rhcalyr rhcalmn thtotinc thearn ehhnumpp tpearn tptotinc ejbhrs1 rfpov ssuid shhadid eentaid epppnum ehrefper rfid ems tage wpfinwgt renroll esex epayhr1 tpyrate1 tpmsum1 epdjbthn eptwrk ehrsall rmesr rmwkwjb rmhrswk
compress
save "${sippdatadirectory}/temp.dta", replace
restore
append using "${sippdatadirectory}/temp.dta"
}

erase "${sippdatadirectory}/temp.dta"


*==================================================
*===== Rename Variables =====
*==================================================
destring epppnum, replace
rename rhcalyr year
rename rhcalmn month
rename tfipsst statefip
order statefip year month

*==================================================
*===== Add Macroeconomics Controls =====
*==================================================
merge m:1 statefip year month using "${additionaldatadirectory}/Macro_Controls.dta", nogenerate
replace index = index/1000
replace unemployment_rate = unemployment_rate/100
replace personal_income = personal_income/1000

gen quarter = 1
replace quarter = 2 if month >= 4 & month <= 6
replace quarter = 3 if month >= 7 & month <= 9
replace quarter = 4 if month >= 10 & month <= 12

*** Merge in BEA Construction Series
merge m:1 statefip year quarter using "${additionaldatadirectory}/ConstructionBEAForMerge.dta"
keep if _merge != 2 
drop _merge
replace construction = construction/100

*** Merge in 05-06 industry share variables
merge m:1 statefip using "${additionaldatadirectory}/QCEW0506indshares.dta"
keep if _merge == 3
drop _merge

*** Merge in House Price Index Match Variables
merge m:1 statefip using "${additionaldatadirectory}/IndexDeclineMatchVariables.dta"
keep if _merge == 3 
drop _merge


*==================================================
*===== Initial Cleaning =====
*==================================================
egen personid = group(ssuid epppnum)
drop if missing(personid)

drop if tage>=65
drop if tage<16

gen time = 100*year+month
drop if time<=200807
drop if time>201207

foreach inc in tpearn {
replace `inc' = `inc'/CPI
replace `inc' = 0 if `inc'<0
replace `inc' = 7500 if `inc' > 7500 & `inc' != .
}

egen personidcount = count(personid), by(personid)
keep if personidcount >= 36


*==================================================
*===== Identify Bound States and =====
*==================================================
preserve 
use "${additionaldatadirectory}/MinimumWageRatesByStateAndMonth.dta", clear
keep if year==2008 & month==1
keep statefip mw
replace mw = round(mw,.01)
rename mw mw2008
save "${additionaldatadirectory}/Jan2008MWs.dta", replace
restore
merge m:1 statefip using "${additionaldatadirectory}/Jan2008MWs.dta", nogenerate
merge m:1 statefip year month using "${additionaldatadirectory}/MinimumWageRatesByStateAndMonth.dta", nogenerate

gen Treatment = mw2008<6.55

gen Post = time>=200908
gen Post1 = time>=200908 & time<=201007
gen Post2 = time>=201008
gen Transition = time>=200905 & time<=200907
gen Period = 0
replace Period = 1 if Transition==1
replace Period = 2 if Post1==1
replace Period = 3 if Post2==1

gen Treatment_Post = Treatment*Post
gen Treatment_Post_1 = Treatment*Post1
gen Treatment_Post_2 = Treatment*Post2
gen Treatment_Trans = Treatment*Transition

gen PeriodSIPP = ""
replace PeriodSIPP = "base" if time >= 200807 & time <= 200904
replace PeriodSIPP = "post" if Period == 2 | Period == 3

*==================================================
*===== Outcome Variables =====
*==================================================
gen employed = rmesr >= 1 & rmesr <= 5
gen noearn = employed==0 | tpmsum1==0
gen intern = employed==1 & tpmsum1==0


*==============================================================
*== Create wage and average baseline wage variables ====
*==============================================================
gen hours = ehrsall
replace hours = 0 if ehrsall<0
gen tothours = hours*rmwkwjb

gen hourwage = tpearn/tothours if ejobcntr >=0
gen hrwage = tpyrate1 if ejobcntr >=0
replace hrwage = hourwage if tpyrate1==0 & !missing(hourwage) 
replace hrwage = round(hrwage,.01)
gen affectedwage = hrwage>=5.15 & hrwage<7.25

gen wagevar = hrwage if  Post==0
egen avewage = mean(wagevar), by(personid)

*==================================================
*== Create Target Samples
*==================================================
*** First grouping uses the baseline approach.
gen group = 0 if avewage== .
replace group = 1 if avewage<7.50
replace group = 2 if avewage>=7.50 & avewage <8.50
replace group = 3 if avewage>=8.50 & avewage <10.00
replace group = 4 if avewage>=10.00 & avewage != . 

*==================================================
*===== Demographic Variables =====
*==================================================
egen minage = min(tage), by(personid)
egen maxedu = max(eeducate), by(personid)
egen maxkids = max(rfnkids), by(personid)
gen morehs = maxedu>39


*==================================================
*===== Geography Variables =====
*==================================================

gen region = 0
replace region = 1 if statefip == 9 | statefip == 23 | statefip == 25 | statefip == 33 | statefip == 44 | statefip == 50
replace region = 1 if statefip == 34 | statefip == 36 | statefip == 42
replace region = 2 if statefip == 17 | statefip == 18 | statefip == 26 | statefip == 39 | statefip == 55 
replace region = 2 if statefip == 19 | statefip == 20 | statefip == 27 | statefip == 29 | statefip == 31 | statefip == 38 | statefip == 46
replace region = 3 if statefip == 10 | statefip == 11 | statefip == 12 | statefip == 13 | statefip == 24 | statefip == 37 | statefip == 45 | statefip == 51 | statefip == 54
replace region = 3 if statefip == 1 | statefip == 21 | statefip == 28 | statefip == 47
replace region = 3 if statefip == 5 | statefip == 22 | statefip == 40 | statefip == 48
replace region = 4 if statefip == 4 | statefip == 8 | statefip == 16 | statefip == 30 | statefip == 32 | statefip == 35 | statefip == 49 | statefip == 56
replace region = 4 if statefip == 2 | statefip == 6 | statefip == 15 | statefip == 41 | statefip == 53

gen regionstring = ""
replace regionstring = "Northeast" if region == 1
replace regionstring = "Midwest" if region == 2
replace regionstring = "South" if region == 3
replace regionstring = "West" if region == 4

gen division = 0
replace division = 1 if statefip == 9 | statefip == 23 | statefip == 25 | statefip == 33 | statefip == 44 | statefip == 50
replace division = 2 if statefip == 34 | statefip == 36 | statefip == 42
replace division = 3 if statefip == 17 | statefip == 18 | statefip == 26 | statefip == 39 | statefip == 55 
replace division = 4 if statefip == 19 | statefip == 20 | statefip == 27 | statefip == 29 | statefip == 31 | statefip == 38 | statefip == 46
replace division = 5 if statefip == 10 | statefip == 11 | statefip == 12 | statefip == 13 | statefip == 24 | statefip == 37 | statefip == 45 | statefip == 51 | statefip == 54
replace division = 6 if statefip == 1 | statefip == 21 | statefip == 28 | statefip == 47
replace division = 7 if statefip == 5 | statefip == 22 | statefip == 40 | statefip == 48
replace division = 8 if statefip == 4 | statefip == 8 | statefip == 16 | statefip == 30 | statefip == 32 | statefip == 35 | statefip == 49 | statefip == 56
replace division = 9 if statefip == 2 | statefip == 6 | statefip == 15 | statefip == 41 | statefip == 53



*==================================================
*===== Summary statistics =====
*==================================================
egen employedlow = wtmean(employed) if group == 1 , by(statefip PeriodSIPP) weight(wpfinwgt)
***** Applying SIPP population weights
**** Summary information on baseline sample variation in the housing decline
bysort Treatment PeriodSIPP: eststo: estpost tabstat personal_income employment_rate unemployment_rate index construction [aw = wpfinwgt], ///
	columns(statistics) statistics(mean sd)

esttab using "${resultsdirectory}\MacroSumStatsSIPPWgt.csv", replace main(mean) label nomtitle nolegend nonotes
estimates clear

**** Summary information on the target group's employment decline within the analysis sample
bysort Treatment PeriodSIPP: eststo: estpost tabstat employed if group == 1 [aw = wpfinwgt], ///
	columns(statistics) statistics(mean sd)
esttab using "${resultsdirectory}\TargetGroupEmpSumStatsSIPPWgt.csv", replace main(mean) label nomtitle nolegend nonotes
estimates clear


***** Not applying SIPP population weights
**** Summary information on baseline sample variation in the housing decline
bysort Treatment PeriodSIPP: eststo: estpost tabstat personal_income employment_rate unemployment_rate index construction, ///
	columns(statistics) statistics(mean sd)

esttab using "${resultsdirectory}\MacroSumStatsSIPP.csv", replace main(mean) label nomtitle nolegend nonotes
estimates clear

**** Summary information on the target group's employment decline within the analysis sample
bysort Treatment PeriodSIPP: eststo: estpost tabstat employed if group == 1 , ///
	columns(statistics) statistics(mean sd)
esttab using "${resultsdirectory}\TargetGroupEmpSumStatsSIPP.csv", replace main(mean) label nomtitle nolegend nonotes
estimates clear


**** Summary information on within-region variation in the housing decline
bysort regionstring Treatment PeriodSIPP: eststo: estpost tabstat personal_income employment_rate unemployment_rate index construction, ///
	columns(statistics) statistics(mean sd)

esttab using "${resultsdirectory}\MacroSumStatsSIPPRegion.csv", replace main(mean) label nonotes
estimates clear
tab regionstring [aw = wpfinwgt] if group == 1 & Treatment == 1



*==================================================
*===== Regression analysis =====
*==================================================
*** First stage effects 
areg mw Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time index if group==1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/FirstStageGroup1BaseSIPP", replace
areg mw Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.region if group==1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/FirstStageGroup1RegSIPP", replace
areg mw Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division if group==1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/FirstStageGroup1DivSIPP", replace
areg mw Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division i.time##c.constructionshare0506 if group==1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/FirstStageGroup1DivConst0506SIPP", replace
areg mw Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##c.constructionshare0506 if group==1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/FirstStageGroup1Const0506SIPP", replace
areg mw Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506)  if group==1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/FirstStageGroup1Ind0506SIPP", replace

*** SIPP baseline regressions
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time if group==0, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup0BaseSIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time if group==1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1BaseSIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time if group==2, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup2BaseSIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time if group==3, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup3BaseSIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time if group==4, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup4BaseSIPP", replace

*** SIPP regression with region variable
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.region if group==0, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup0RegSIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.region if group==1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1RegSIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.region if group==2, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup2RegSIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.region if group==3, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup3RegSIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.region if group==4, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup4RegSIPP", replace

*** SIPP regression with division variable (groups 0 through 4)
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division if group==0, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup0DivSIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division if group==1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1DivSIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division if group==2, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup2DivSIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division if group==3, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup3DivSIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division if group==4, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup4DivSIPP", replace

*** SIPP regression with division and construction variables
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division i.time##c.constructionshare0506 if group==0, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup0DivConst0506SIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division i.time##c.constructionshare0506 if group==1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1DivConst0506SIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division i.time##c.constructionshare0506 if group==2, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup2DivConst0506SIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division i.time##c.constructionshare0506 if group==3, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup3DivConst0506SIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division i.time##c.constructionshare0506 if group==4, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup4DivConst0506SIPP", replace

**** Estimates with Spatial Controls and No FL or AZ
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time if statefip != 12 & statefip != 4 & group== 1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1BaseSIPPNoFLAZ", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.region if statefip != 12 & statefip != 4 & group== 1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1RegSIPPNoFLAZ", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division if statefip != 12 & statefip != 4 & group== 1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1DivSIPPNoFLAZ", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division i.time##c.constructionshare0506 if statefip != 12 & statefip != 4 & group== 1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1DivConst0506SIPPNoFLAZ", replace

**** Estimates with Spatial Controls and Housing Match 01
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time if ismatched01 == 1 & group== 1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1BaseSIPPMatch", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.region if ismatched01 == 1 & group== 1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1RegSIPPMatch", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division if ismatched01 == 1 & group== 1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1DivSIPPMatch", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division i.time##c.constructionshare0506 if ismatched01 == 1 & group== 1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1DivConst0506SIPPMatch", replace

**** Estimates with Spatial Controls and Housing Match 02
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time if ismatched02 == 1 & group== 1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1BaseSIPPMatch02", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.region if ismatched02 == 1 & group== 1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1RegSIPPMatch02", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division if ismatched02 == 1 & group== 1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1DivSIPPMatch02", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division i.time##c.constructionshare0506 if ismatched02 == 1 & group== 1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1DivConst0506SIPPMatch02", replace


*** SIPP regression with Construction share variable
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##c.constructionshare0506 if group==0, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup0Const0506SIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##c.constructionshare0506 if group==1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1Const0506SIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##c.constructionshare0506 if group==2, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup2Const0506SIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##c.constructionshare0506 if group==3, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup3Const0506SIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##c.constructionshare0506 if group==4, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup4Const0506SIPP", replace

*** SIPP regression with industry share variables (across groups 0 through 4)
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506)  if group==0, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup0Ind0506SIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506)  if group==1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1Ind0506SIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506)  if group==2, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup2Ind0506SIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506)  if group==3, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup3Ind0506SIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506)  if group==4, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup4Ind0506SIPP", replace


**** SIPP Estimates with Industry Controls and No FL or AZ
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time if statefip != 12 & statefip != 4 & group== 1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1BaseSIPPNoFLAZ", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##c.constructionshare0506 if statefip != 12 & statefip != 4 & group== 1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1Const0506SIPPNoFLAZ", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506) if statefip != 12 & statefip != 4 & group== 1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1Ind0506SIPPNoFLAZ", replace

**** SIPP Estimates with Industry Controls and Housing Match 01
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time if ismatched01 == 1 & group== 1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1BaseSIPPMatch", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##c.constructionshare0506 if ismatched01 == 1 & group== 1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1Const0506SIPPMatch", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506) if ismatched01 == 1 & group== 1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1Ind0506SIPPMatch", replace

**** SIPP Estimates with Industry Controls and Housing Match 02
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time if ismatched02 == 1 & group== 1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1BaseSIPPMatch02", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##c.constructionshare0506 if ismatched02 == 1 & group== 1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1Const0506SIPPMatch02", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506) if ismatched02 == 1 & group== 1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1Ind0506SIPPMatch02", replace




capture log close
